//MQL4 code that uses a 103 length Exponential Moving Average (EMA) and a 10 period Trend Direction Force Index (TDFI) to generate buy and sell signals:

//+------------------------------------------------------------------+
//|                                                  TEST1_SCALP.mq4 |
//|                 Copyright 2021, Your Name                        |
//|                           https://www.example.com                |
//+------------------------------------------------------------------+

#property copyright "2021, Your Name"
#property link      "https://www.example.com"
#property version   "1.0"
#property strict

extern int MagicNumber = 12345; // Magic Number to identify trades

// Input parameters
input int EmaPeriod = 103;      // EMA period
input int TdfiPeriod = 10;      // TDFI period
input double TdfiLevel = 0.05;   // TDFI level for buy/sell signals

// Global variables
double ema;                     // EMA value
double tdfi;                    // TDFI value
double prev_tdfi;               // Previous TDFI value
int TicketNumber;

// Initialization function
int OnInit()
{
    // Calculate the EMA for the current symbol and timeframe
    ema = iMA(_Symbol, _Period, EmaPeriod, 0, MODE_EMA, PRICE_CLOSE, 0);

    // Initialize the TDFI values
    tdfi = 0.0;
    prev_tdfi = 0.0;

    return(INIT_SUCCEEDED);
}

// Trading function
void OnTick()
{
    // Calculate the TDFI for the current symbol and timeframe
    tdfi = iCustom(_Symbol, _Period, "TDFI", TdfiPeriod,1,0);

    // Check for a buy signal
    if (tdfi > TdfiLevel && prev_tdfi <= TdfiLevel && Close[0] > ema)
    {
      TicketNumber = OrderSend(_Symbol, OP_BUY, 0.1, Ask, 3, 1, 2, "EMA_TDFI_BUY", MagicNumber, 0, Blue);

      if( TicketNumber > 0 )
      {
       Print("Order placed # ", TicketNumber);
      }
      else
      {
         Print("Order Send failed, error # ", GetLastError() );
      }
    
        
    }

    // Check for a sell signal
    if (tdfi < -TdfiLevel && prev_tdfi >= -TdfiLevel && Close[0] < ema)
    {
      TicketNumber = OrderSend(_Symbol, OP_BUY, 0.1, Ask, 3, 1, 2, "EMA_TDFI_BUY", MagicNumber, 0, Blue);

      if( TicketNumber > 0 )
      {
       Print("Order placed # ", TicketNumber);
      }
      else
      {
         Print("Order Send failed, error # ", GetLastError() );
      }
    }

    // Update the previous TDFI value
    prev_tdfi = tdfi;
}
